@@ -4,6 +4,7 @@ class JACException(Exception):
     """
     pass
 
+
 class OfflineGenerationError(JACException):
     """
     Offline compression generation related exceptions
@@ -23,3 +24,10 @@ class TemplateSyntaxError(JACException):
     This exception is raised when a template syntax error is encountered.
     """
     pass
+
+
+class InvalidCompressorError(JACException):
+    """
+    This exception is raised when a compressor is not setup correctly.
+    """
+    pass
